@@ -18,11 +18,11 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "config.h"
 
 #include "peas-plugin-loader-python.h"
 #include "peas-python-internal.h"
@@ -34,21 +34,18 @@
 #undef _POSIX_C_SOURCE
 #include <pygobject.h>
 
-typedef struct {
+struct _PeasPluginLoaderPython {
+  PeasPluginLoader parent_instance;
+
   PyThreadState *py_thread_state;
 
   guint n_loaded_plugins;
 
   guint init_failed : 1;
   guint must_finalize_python : 1;
-} PeasPluginLoaderPythonPrivate;
+};
 
-G_DEFINE_TYPE_WITH_PRIVATE (PeasPluginLoaderPython,
-                            peas_plugin_loader_python,
-                            PEAS_TYPE_PLUGIN_LOADER)
-
-#define GET_PRIV(o) \
-  (peas_plugin_loader_python_get_instance_private (o))
+G_DEFINE_FINAL_TYPE (PeasPluginLoaderPython, peas_plugin_loader_python, PEAS_TYPE_PLUGIN_LOADER)
 
 static GQuark quark_extension_type = 0;
 
@@ -102,7 +99,7 @@ peas_plugin_loader_python_provides_extension (PeasPluginLoader *loader,
 }
 
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-static PeasExtension *
+static GObject *
 peas_plugin_loader_python_create_extension (PeasPluginLoader *loader,
                                             PeasPluginInfo   *info,
                                             GType             exten_type,
@@ -135,7 +132,7 @@ peas_plugin_loader_python_create_extension (PeasPluginLoader *loader,
                       GSIZE_TO_POINTER (exten_type));
 
   pyobject = pygobject_new (object);
-  pyplinfo = pyg_boxed_new (PEAS_TYPE_PLUGIN_INFO, info, TRUE, TRUE);
+  pyplinfo = pygobject_new (G_OBJECT (info));
 
   /* Set the plugin info as an attribute of the instance */
   if (PyObject_SetAttrString (pyobject, "plugin_info", pyplinfo) != 0)
@@ -157,14 +154,14 @@ out:
   PyGILState_Release (state);
   return object;
 }
+G_GNUC_END_IGNORE_DEPRECATIONS
 
 static gboolean
 peas_plugin_loader_python_load (PeasPluginLoader *loader,
                                 PeasPluginInfo   *info)
 {
   PeasPluginLoaderPython *pyloader = PEAS_PLUGIN_LOADER_PYTHON (loader);
-  PeasPluginLoaderPythonPrivate *priv = GET_PRIV (pyloader);
-  const gchar *module_dir, *module_name;
+  const char *module_dir, *module_name;
   PyObject *pymodule;
   PyGILState_STATE state = PyGILState_Ensure ();
 
@@ -178,26 +175,24 @@ peas_plugin_loader_python_load (PeasPluginLoader *loader,
   if (pymodule != NULL)
     {
       info->loader_data = pymodule;
-      priv->n_loaded_plugins += 1;
+      pyloader->n_loaded_plugins += 1;
     }
 
   PyGILState_Release (state);
   return pymodule != NULL;
 }
-G_GNUC_END_IGNORE_DEPRECATIONS
 
 static void
 peas_plugin_loader_python_unload (PeasPluginLoader *loader,
                                   PeasPluginInfo   *info)
 {
   PeasPluginLoaderPython *pyloader = PEAS_PLUGIN_LOADER_PYTHON (loader);
-  PeasPluginLoaderPythonPrivate *priv = GET_PRIV (pyloader);
   PyGILState_STATE state = PyGILState_Ensure ();
 
   /* We have to use this as a hook as the
    * loader will not be finalized by applications
    */
-  if (--priv->n_loaded_plugins == 0)
+  if (--pyloader->n_loaded_plugins == 0)
     peas_python_internal_call ("all_plugins_unloaded", NULL, NULL);
 
   Py_CLEAR (info->loader_data);
@@ -218,7 +213,6 @@ static gboolean
 peas_plugin_loader_python_initialize (PeasPluginLoader *loader)
 {
   PeasPluginLoaderPython *pyloader = PEAS_PLUGIN_LOADER_PYTHON (loader);
-  PeasPluginLoaderPythonPrivate *priv = GET_PRIV (pyloader);
   PyGILState_STATE state = 0;
   long hexversion;
 
@@ -234,7 +228,7 @@ peas_plugin_loader_python_initialize (PeasPluginLoader *loader)
   else
     {
       Py_InitializeEx (FALSE);
-      priv->must_finalize_python = TRUE;
+      pyloader->must_finalize_python = TRUE;
     }
 
   hexversion = PyLong_AsLong (PySys_GetObject ((char *) "hexversion"));
@@ -265,23 +259,22 @@ peas_plugin_loader_python_initialize (PeasPluginLoader *loader)
 
   /* Initialize support for threads */
   pyg_enable_threads ();
-  PyEval_InitThreads ();
 
   /* Only redirect warnings when python was not already initialized */
-  if (!priv->must_finalize_python)
+  if (!pyloader->must_finalize_python)
     pyg_disable_warning_redirections ();
 
   /* Must be done last, finalize() depends on init_failed */
-  if (!peas_python_internal_setup (!priv->must_finalize_python))
+  if (!peas_python_internal_setup (!pyloader->must_finalize_python))
     {
       /* Already warned */
       goto python_init_error;
     }
 
-  if (!priv->must_finalize_python)
+  if (!pyloader->must_finalize_python)
     PyGILState_Release (state);
   else
-    priv->py_thread_state = PyEval_SaveThread ();
+    pyloader->py_thread_state = PyEval_SaveThread ();
 
   return TRUE;
 
@@ -293,10 +286,10 @@ python_init_error:
   g_warning ("Please check the installation of all the Python "
              "related packages required by libpeas and try again");
 
-  if (!priv->must_finalize_python)
+  if (!pyloader->must_finalize_python)
     PyGILState_Release (state);
 
-  priv->init_failed = TRUE;
+  pyloader->init_failed = TRUE;
   return FALSE;
 }
 
@@ -309,27 +302,26 @@ static void
 peas_plugin_loader_python_finalize (GObject *object)
 {
   PeasPluginLoaderPython *pyloader = PEAS_PLUGIN_LOADER_PYTHON (object);
-  PeasPluginLoaderPythonPrivate *priv = GET_PRIV (pyloader);
   PyGILState_STATE state;
 
   if (!Py_IsInitialized ())
     goto out;
 
-  g_warn_if_fail (priv->n_loaded_plugins == 0);
+  g_warn_if_fail (pyloader->n_loaded_plugins == 0);
 
-  if (!priv->init_failed)
+  if (!pyloader->init_failed)
     {
       state = PyGILState_Ensure ();
       peas_python_internal_shutdown ();
       PyGILState_Release (state);
     }
 
-  if (priv->py_thread_state)
-    PyEval_RestoreThread (priv->py_thread_state);
+  if (pyloader->py_thread_state)
+    PyEval_RestoreThread (pyloader->py_thread_state);
 
-  if (priv->must_finalize_python)
+  if (pyloader->must_finalize_python)
     {
-      if (!priv->init_failed)
+      if (!pyloader->init_failed)
         PyGILState_Ensure ();
 
       Py_Finalize ();
